#include <iostream>
#include <fstream>
#include <cassert>
#include <regex>
#include <string>
#include <stack>
#include <vector>
#include <map>
#include <set>

using std::ifstream; using std::ofstream; using std::endl; using std::ws;
using std::getline;
using std::string; using std::vector; using std::map; using std::set;
using std::smatch; using std::regex;
using std::regex_search;
using std::regex_match;
using std::make_pair; using std::pair;

#define ERR_OK (0)
#define ERR_WA (1)
#define ERR_PE (2)
#define ERR_UH (3)

static const regex ex1("\\s*\"([A-Za-z0-9\\-\\. ]+|~)\"\\s*(\"([A-Za-z0-9\\-\\. ]+|~)\")?\\s*$");

#define MAXLEN (64)
#define GROUP1 (1)
#define GROUP2 (3)

typedef pair<int, string> error;

size_t test(ifstream &src, map<string, int> &FileTable, map<int, set<string> > &Target, int i0) {
	size_t num, sum = 0; string cmd, str; smatch res;
	if (!(src >> num >> ws)) throw error(ERR_PE, "Could not read the number!");
	for (int cid, id = i0, i = 0; i < num; ++ i) {
		src >> cmd >> ws; cid = 0;
		if (cmd == "new") cid = 1;
		if (cmd == "del") cid = 2;
		if (cmd == "cpy") cid = 3;
		if (cmd == "mov") cid = 4;
		if (!cid) {
			throw error(ERR_PE, "Incorrect command in output!");
		}
		if (!getline(src, str)) {
			throw error(ERR_PE, "Unexpected end of file!");
		}
		if (str.size() > 1024) {
			throw error(ERR_PE, "Too large string in output!");
		}
		if (!regex_match(str, res, ex1)) {
			throw error(ERR_PE, "Incorrect arguments!");
		}
		if ((res[GROUP1].str().size() > MAXLEN) || (res[GROUP2].str().size() > MAXLEN)) {
			throw error(ERR_PE, "Too large argument!");
		}
		if ((cid < 3) && (res[GROUP2] != "")) {
			throw error(ERR_PE, "Too many arguments!");
		}
		static const size_t WEIGHT[] = {0, 100, 1, 10, 1};
		sum += WEIGHT[cid];
		if (cid == 1) {
			if (FileTable.count(res[GROUP1])) {
				throw error(ERR_WA, "Attempt to rewrite existing file!");
			}
			FileTable[res[GROUP1]] = id;
			Target[id].insert(res[GROUP1]);
			++ id;
			continue;
		}
		if (cid == 2) {
			if (!FileTable.count(res[GROUP1])) {
				throw error(ERR_WA, "Target for deleting is not found!");
			}
			int t = FileTable[res[GROUP1]];
			Target[t].erase(res[GROUP1]);
			if (!Target[t].size()) Target.erase(t);
			FileTable.erase(res[GROUP1]);
			continue;
		}
		if (res[GROUP2] == "") throw error(ERR_PE, "Too few arguments!");
		if (!FileTable.count(res[GROUP1])) {
			throw error(ERR_WA, "Source file does not exist!");
		}
		if (FileTable.count(res[GROUP2])) {
			string msg = (cid == 3)? ("copying"): ("moving");
			throw error(ERR_WA, "Target for " + msg +
			                    " already exists!");
		}
		int t = FileTable[res[GROUP1]];
		Target[t].insert(res[GROUP2]);
		FileTable[res[GROUP2]] = t;
		if (cid == 4) {
			Target[t].erase(res[GROUP1]);
			if (!Target[t].size()) Target.erase(t);
			FileTable.erase(res[GROUP1]);
		}
	}
	if (!(src >> ws).eof()) {
		throw error(ERR_PE, "Extra characters in output!");
	}
	return sum;
}

int main(int arc, char *argv[]) {

	static map<int, set<string> > MANS, MOUT; map<string, int> TANS, TOUT;
	string str; smatch res; size_t len, sans, sout; int id;

	ifstream finp(argv[1]); finp >> len >> ws;
	for (id = 0; id < len; ++ id) {
		getline(finp, str); regex_search(str, res, ex1);
		MANS[TANS[res[1]] = id].insert(res[1]);
		MOUT[TOUT[res[1]] = id].insert(res[1]);
	}
	finp.close();

	ifstream fans(argv[3]); if (!fans.is_open()) return ERR_UH;
	try {
		sans = test(fans, TANS, MANS, id);
	}
	catch (error err) {
		return ERR_UH;
	}
	fans.close();

	ifstream fout(argv[2]);
	if (!fout.is_open()) {
		std::cout << "Output file is not found!\n";
		return ERR_PE;
	}
	try {
		sout = test(fout, TOUT, MOUT, id);
	}
	catch (error err) {
		std::cout << err.second << "\n";
		return err.first;
	}
	catch (...) {
		std::cout << "Output file is not read!\n";
		return ERR_PE;
	}
	fout.close();

	if (sout > sans) {
		std::cout << "Solution is not optimal!\n";
		return ERR_WA;
	}
	set<set<string> > SANS, SOUT;
	for (auto it = MANS.find(id); it != MANS.end(); ) {
		SANS.emplace(it->second);
		MANS.erase(it ++);
	}
	for (auto it = MOUT.find(id); it != MOUT.end(); ) {
		SOUT.emplace(it->second);
		MOUT.erase(it ++);
	}
	if ((MANS != MOUT) || (SANS != SOUT)) {
		return ERR_WA;
	}

	return ERR_OK;
}
