#include <fstream>
#include <cassert>
#include <regex>
#include <string>
#include <stack>
#include <vector>
#include <map>
#include <set>

#pragma comment(linker, "/STACK:4000000")

using std::ifstream; using std::ofstream; using std::endl; using std::ws; using std::getline;
using std::string; using std::stack; using std::vector; using std::map; using std::set;
using std::smatch; using std::regex;
using std::regex_search;
using std::regex_match;
using std::pair; using std::make_pair;

static const regex ex1("^\"([^/\"]+)\"\\s*"), ex2("^\"([^/\"]+)\"\\s*(\"([^/\"]+)\")?");
static map<int, set<string> > TargetList; static map<int, string> SourceName;
static map<string, int> OldFileTable;
static map<string, int> NewFileTable;
static vector<pair<string, vector<string> > > CpyFileQueue;
static vector<string> NewFileQueue;
vector<string> OutString;
vector<bool> MARK;

//Выполняет поиск и устранение циклов (если это возможно):
bool dfs(int id) {
	if (MARK[id]) return false;
	MARK[id] = 1;
	auto i1 = TargetList[id].begin(), i0 = TargetList[id].end();
	for (; i1 != i0; ++ i1) {
		if (OldFileTable.count(*i1) && !dfs(OldFileTable[*i1])) continue;
		//Если достигли конца незамкнутой цепочки --- перемещаем файл:
		OutString.push_back("mov \"" + SourceName[id] + "\" \"" + *i1 + "\"");
		OldFileTable.erase(SourceName[id]);
		//Сохраняем все оставшиеся копии перемещенного файла:
		CpyFileQueue.push_back(make_pair(*i1, vector<string> ()));
		TargetList[id].erase(i1);
		auto j1 = TargetList[id].begin();
		auto j0 = TargetList[id].end();
		for (; j1 != j0; ++ j1) {
			CpyFileQueue.back().second.push_back(*j1);
		}
		//SourceName.erase(id);
		TargetList.erase(id);
		return true;
	}
	//Имеет место неразрешимый цикл:
	//[он будет обработан ниже]
	MARK[id] = 0;
	return false;
}

//Проверяет необходимость перемещения текущего файла:
bool chk(int id) {
	auto i1 = TargetList[id].begin(), i0 = TargetList[id].end();
	for (; i1 != i0; ++ i1) {
		if (*i1 != SourceName[id]) continue;
		TargetList[id].erase(i1);
		MARK[id] = 1;
		return true;
	}
	return false;
}

int main() {

	size_t len, num; string str, cmd; smatch res; int id;

	//Считываем содержимое исходного каталога:
	ifstream finp("input.txt"); finp >> len >> ws;
	for (id = 0; id < len; ++ id) {
		getline(finp, str); regex_search(str, res, ex1);
		SourceName[OldFileTable[res[1]] = id] = res[1]; TargetList[id].insert(res[1]);
	}
	//Читаем и выполняем заданные команды:
	NewFileTable = OldFileTable;
	finp >> num >> ws;
	for (int i = 0; i < num; ++ i) {
		finp >> cmd >> ws; getline(finp, str); regex_search(str, res, ex2);
		if (cmd == "new") {
			TargetList[NewFileTable[res[1]] = id].insert(res[1]);
			++ id;
			continue;
		}
		int t = NewFileTable[res[1]];
		if (cmd == "del") {
			TargetList[t].erase(res[1]); NewFileTable.erase(res[1]);
			continue;
		}
		TargetList[t].insert(res[3]); NewFileTable[res[3]] = t;
		if (cmd == "mov") {
			TargetList[t].erase(res[1]); NewFileTable.erase(res[1]);
		}
	}
	for (auto it = TargetList.begin(); it != TargetList.end(); ) {
		if (!(it->second.size())) {
			TargetList.erase(it ++);
			continue;
		}
		++ it;
	}
	MARK.resize(id + 1, 0);
	finp.close();

	//Выполняем удаление старых файлов, которых нет в новом каталоге:
	for (auto it = SourceName.begin(); it != SourceName.end(); ) {
		if (!TargetList.count(it->first)) {
			OutString.push_back("del \"" + it->second + "\"");
			OldFileTable.erase(it->second);
			MARK[it->first] = 1;
			SourceName.erase(it ++);
			continue;
		}
		++ it;
	}
	//Формируем очередь на добавление новых файлов:
	for (auto it = TargetList.begin(); it != TargetList.end(); ) {
		if (!SourceName.count(it->first)) {
			//Если новый файл успел обзавестись своими копиями:
			auto i2 = it->second.begin();
			auto i0 = it->second.end();
			CpyFileQueue.push_back(make_pair(*i2, vector<string> ()));
			NewFileQueue.push_back(*i2);
			for (++ i2; i2 != i0; ++ i2) {
				CpyFileQueue.back().second.push_back(*i2);
			}
			TargetList.erase(it ++);
			continue;
		}
		++ it;
	}
	//Формируем очередь на копирование старых файлов:
	for (auto it = SourceName.begin(); it != SourceName.end(); ) {
		if (!chk(it->first)) { ++ it; continue; }
		auto i1 = TargetList[it->first].begin();
		auto i0 = TargetList[it->first].end();
		CpyFileQueue.push_back(make_pair(it->second, vector<string> ()));
		for (; i1 != i0; ++ i1) {
			CpyFileQueue.back().second.push_back(*i1);
		}
		SourceName.erase(it ++);
	}
	//Выполняем перемещение старых файлов:
	stack<string> STACK;
	for (auto it = SourceName.begin(); it != SourceName.end(); ) {
		auto it2 = it; ++ it2;
		if (MARK[it->first] || dfs(it->first)) { it = it2; continue; }
		string st = *(TargetList[it->first].begin());
		while (st != it->second) {
			int t = OldFileTable[st]; STACK.push(st);
			assert(TargetList[t].size() == 1);
			MARK[t] = 1;
			st = *(TargetList[t].begin());
		}
		MARK[it->first] = 1;
		OutString.push_back("mov \"" + it->second + "\" \"~\"");
		st = it->second;
		while (!STACK.empty()) {
			OutString.push_back("mov \"" + STACK.top() + "\" \"" + st + "\"");
			st = STACK.top();
			STACK.pop();
		}
		OutString.push_back("mov \"~\" \"" + st + "\"");
		++ it;
	}
	//Добавляем новые файлы:
	for (int i = 0; i < NewFileQueue.size(); ++ i) {
		OutString.push_back("new \"" + NewFileQueue[i] + "\"");
	}
	//Копируем файлы:
	for (int i = 0; i < CpyFileQueue.size(); ++ i) {
		string st = CpyFileQueue[i].first;
		auto i2 = CpyFileQueue[i].second.begin();
		auto i0 = CpyFileQueue[i].second.end();
		for (; i2 != i0; ++ i2) {
			OutString.push_back("cpy \"" + st + "\" \"" + *i2 + "\"");
		}
	}
	//...
	ofstream fout("output.txt"); fout << OutString.size() << "\n";
	for (int i = 0; i < OutString.size(); ++ i) {
		fout << OutString[i] << "\n";
	}
	fout.close();

	return 0;
}
